@@ -293,7 +293,8 @@ class ResponseObject(object):
 		else:
 			return json.dumps(self.dict(), indent=4)
 	def json(self,):
-		return json.dumps(self.dictionary(serializable=True), indent=4)
+		return self.dict(serializable=True)
+		return json.dumps(self.dict(serializable=True), indent=4)
 		return json.dumps(self)
 		return json.dumps(self, default=lambda o: o.__dict__)
 	#def __dict__(self):
